@@ -1,19 +1,21 @@
-use crate::args::{
-    Args, BalancesArgs, Command, DistributeTokensArgs, SenderStakeArgs, SplTokenArgs, StakeArgs,
-    TransactionLogArgs,
+use {
+    crate::args::{
+        Args, BalancesArgs, Command, DistributeTokensArgs, SenderStakeArgs, SplTokenArgs,
+        StakeArgs, TransactionLogArgs,
+    },
+    clap::{
+        crate_description, crate_name, value_t, value_t_or_exit, App, Arg, ArgMatches, SubCommand,
+    },
+    solana_clap_utils::{
+        input_parsers::{pubkey_of_signer, value_of},
+        input_validators::{is_amount, is_valid_pubkey, is_valid_signer},
+        keypair::{pubkey_from_path, signer_from_path},
+    },
+    solana_cli_config::CONFIG_FILE,
+    solana_remote_wallet::remote_wallet::maybe_wallet_manager,
+    solana_sdk::native_token::sol_to_lamports,
+    std::{error::Error, ffi::OsString, process::exit},
 };
-use clap::{
-    crate_description, crate_name, value_t, value_t_or_exit, App, Arg, ArgMatches, SubCommand,
-};
-use solana_clap_utils::{
-    input_parsers::{pubkey_of_signer, value_of},
-    input_validators::{is_amount, is_valid_pubkey, is_valid_signer},
-    keypair::{pubkey_from_path, signer_from_path},
-};
-use solana_cli_config::CONFIG_FILE;
-use solana_remote_wallet::remote_wallet::maybe_wallet_manager;
-use solana_sdk::native_token::sol_to_lamports;
-use std::{error::Error, ffi::OsString, process::exit};
 
 fn get_matches<'a, I, T>(args: I) -> ArgMatches<'a>
 where
